#ifndef __IUF_GAMEOBJT
#define __IUF_GAMEOBJT
#include <math.h>
#include <vcg/Point3.h>
#include <vcg/Sphere3.h>
#include <vector>
#include <list>

#ifndef M_PI
#define M_PI 3.14159265358979323846
#endif

/** This class represent a generic game object with a limited time 
to live (explosions, bullet, fragments).

Version History {\small 
\begin{itemize}
\item 0.4s First Release.
\end{itemize}
}
*/
using namespace vcg;
using namespace std;
class GameObjTimed : public GameObj
{
 public:

	 /// default constructor
	 GameObjTimed():GameObj(){}
	 /// constructor with given position and direction
	 GameObjTimed(const Point3f &_p, const float _a):GameObj(_p,_a){}
	/// constructor with given position and direction and velocity
	 GameObjTimed(const Point3f &_p, const float _a, const Point3f &_v):GameObj(_p,_a,_v){}

 
 
 /** Time To Live (expressed in msec).
	Time that the object has before it disappear. 
	Once the ttl become <= 0 the object become 
	not active and someone will remove it from the Active objects list */
	int ttl;


	 	/** It must update and check the remaining Time To Live (TTL) of the object
	and disactivating it if necessary. */
	void Update(int t)
	{
		ttl-=t;
		if(ttl<0) active=false;
		GameObj::Update(t);
	}

};

#endif // ifndef __IUF_GAMEOBJT